/**
* [permissionsList List of Android permissions needed in the app]
*/
var permissionsList = {
  readStorage: 'android.permission.READ_EXTERNAL_STORAGE',
  writeStorage: 'android.permission.WRITE_EXTERNAL_STORAGE',
  coarseLocation: 'android.permission.ACCESS_COARSE_LOCATION',
  fineLocation: 'android.permission.ACCESS_FINE_LOCATION'
};

/**
* [permissionsDialog message and title for AlertDialog]
*/
var permissionsDialog = {
  storage: {
    title: 'Access to the storage was denied',
    message: 'Ventra uses the storage to keep your information updated. You can change the storage permission in the application settings.'
  },
  location: {
    title: 'Access to location was denied',
    message: 'Ventra uses the location to give a better service. You can change the location permission in the application settings.'
  }
};

/**
* [verifyStoragePermissions]
*/
var verifyStoragePermissions = function() {
  console.log('[androidPermissions] - verifyStoragePermissions');
  if (OS_IOS) {
    return true;
  }

  return Ti.Android.hasPermission(permissionsList.readStorage) && Ti.Android.hasPermission(permissionsList.writeStorage);
};

var verifyLocationPermissions = function() {
  console.log('[androidPermissions] - verifyLocationPermissions');
  if (OS_IOS) {
    return true;
  }

  return Ti.Android.hasPermission(permissionsList.coarseLocation) && Ti.Android.hasPermission(permissionsList.fineLocation);
};

/**
* [openSettingsDialog create an alert when the user continue denying the permission. This prevent a blocker if the user check the "Never ask again" checkbox]
*/
var openSettingsDialog = function(permissionName) {
  var openSettingsDialog = Ti.UI.createAlertDialog({
    cancel: 0,
    buttonNames: ['Don\'t Allow', 'Open Application Settings'],
    message: permissionsDialog[permissionName].message,
    title: permissionsDialog[permissionName].title
  });

  openSettingsDialog.addEventListener('click', function(e) {
    if (e.index !== e.source.cancel) {
      var intent = Ti.Android.createIntent({
        action: 'android.settings.APPLICATION_SETTINGS'
      });

      intent.addFlags(Ti.Android.FLAG_ACTIVITY_NEW_TASK);
      Ti.Android.currentActivity.startActivity(intent);
    }
  });

  setTimeout(function(){
    openSettingsDialog.show();
  }, 1000);
};

/**
* [requestPermissions Shows popup alert to request permissions Android only]
*/
var requestPermissions = function(permissionName, permissionsArray, callback) {
  if (OS_ANDROID && permissionsArray.length > 0) {
    Ti.Android.requestPermissions(permissionsArray, function(e) {
      callback(e.success);

      if (!e.success) {
        openSettingsDialog(permissionName);
      }
    });
  } else {
    callback(true);
  }
};

/**
* [showGrantPermissionView Opens grantPermission controller to retry request permissions]
*/
var showGrantPermissionView = function() {
  var grantPermissionController = Alloy.createController('grantPermission').getView();
  grantPermissionController.open();
};

exports.permissionsList = permissionsList;
exports.requestPermissions = requestPermissions;
exports.showGrantPermissionView = showGrantPermissionView;
exports.verifyLocationPermissions = verifyLocationPermissions;
exports.verifyStoragePermissions = verifyStoragePermissions;
